@@ -14,7 +14,11 @@ import doctest
 import PyNormaliz
 skip = set()
 if not PyNormaliz.NmzHasEAntic():
+    skip.add("equation-41.txt")
     skip.add("segfault-27.txt")
+    skip.add("segfault-35.txt")
+    skip.add("vertex_denom-37.txt")
+    skip.add("modify_cone_renf.txt")
 
 # run doctests
 attempted = failed = 0
@@ -37,8 +41,9 @@ for filename in os.listdir(os.curdir):
 
 
 # unit tests
-import generic_test
+from generic_test import tests
 
-generic_test.Test1(verbose=False).run(repeat=100)
+for test in tests:
+    failed += test(verbosity=2).run(repeat=10)
 
 sys.exit(failed)
