@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2014  Winfried Bruns, Bogdan Ichim, Christof Soeger
+ * Copyright (C) 2007-2019  Winfried Bruns, Bogdan Ichim, Christof Soeger
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -29,68 +29,72 @@
 #include <algorithm>
 using namespace std;
 
-#include "libnormaliz/libnormaliz.h"
 #include "libnormaliz/cone.h"
+#include "libnormaliz/output.h"
 using namespace libnormaliz;
 
-#include "normaliz.h"
 #include "options.h"
-#include "output.h"
 
+void printHeader();
+void printCopying();
+void printVersion();
 
 OptionsHandler::OptionsHandler() {
     project_name_set = false;
-    output_dir_set=false;
+    output_dir_set = false;
     write_extra_files = false, write_all_files = false;
     // use_Big_Integer = false;
     use_long_long = false;
     ignoreInFileOpt = false;
     nr_threads = 0;
-    no_ext_rays_output=false;
-    no_supp_hyps_output=false;
-    no_matrices_output=false;
+    no_ext_rays_output = false;
+    no_supp_hyps_output = false;
+    no_matrices_output = false;
 }
 
-
 bool OptionsHandler::handle_commandline(int argc, char* argv[]) {
-        vector<string> LongOptions;
-        string ShortOptions; //all options concatenated (including -)
-        // read command line options
-        for (int i = 1; i < argc; i++) {
-                if (argv[i][0] == '-') {
-                        if (argv[i][1] != '\0') {
-                                if (argv[i][1] != 'x') {
-                                        if (argv[i][1] == '-') {
-                                                string LO = argv[i];
-                                                LO.erase(0, 2);
-                                                LongOptions.push_back(LO);
-                                        } else
-                                                ShortOptions = ShortOptions + argv[i];
-                                } else if (argv[i][2] == '=') {
-                        #ifdef _OPENMP
-                        string Threads = argv[i];
-                        Threads.erase(0,3);
-                        if ( (istringstream(Threads) >> nr_threads) && nr_threads >= 0) {
-                            set_thread_limit(nr_threads);
-                            // omp_set_num_threads(nr_threads); -- now in cone.cpp
-                        } else {
-                            cerr<<"Error: Invalid option string "<<argv[i]<<endl;
-                        exit(1);
-                        }
-                    #else
-                                        cerr << "Warning: Compiled without OpenMP support, option "
-                                                        << argv[i] << " ignored." << endl;
-                                        #endif
-                                } else {
-                                        cerr << "Error: Invalid option string " << argv[i] << endl;
-                                        exit(1);
-                                }
-                        }
-                } else {
-                    setProjectName(argv[i]);
+    vector<string> LongOptions;
+    string ShortOptions;  // all options concatenated (including -)
+    // read command line options
+    for (int i = 1; i < argc; i++) {
+        if (argv[i][0] == '-') {
+            if (argv[i][1] != '\0') {
+                if (argv[i][1] != 'x') {
+                    if (argv[i][1] == '-') {
+                        string LO = argv[i];
+                        LO.erase(0, 2);
+                        LongOptions.push_back(LO);
+                    }
+                    else
+                        ShortOptions = ShortOptions + argv[i];
                 }
+                else if (argv[i][2] == '=') {
+#ifdef _OPENMP
+                    string Threads = argv[i];
+                    Threads.erase(0, 3);
+                    if ((istringstream(Threads) >> nr_threads) && nr_threads >= 0) {
+                        set_thread_limit(nr_threads);
+                        // omp_set_num_threads(nr_threads); -- now in cone.cpp
+                    }
+                    else {
+                        cerr << "Error: Invalid option string " << argv[i] << endl;
+                        exit(1);
+                    }
+#else
+                    cerr << "Warning: Compiled without OpenMP support, option " << argv[i] << " ignored." << endl;
+#endif
+                }
+                else {
+                    cerr << "Error: Invalid option string " << argv[i] << endl;
+                    exit(1);
+                }
+            }
         }
-        return handle_options(LongOptions, ShortOptions);
+        else {
+            setProjectName(argv[i]);
+        }
+    }
+    return handle_options(LongOptions, ShortOptions);
 }
 
 void OptionsHandler::setProjectName(const string& s) {
@@ -100,42 +104,43 @@ void OptionsHandler::setProjectName(const string& s) {
     }
     project_name = s;
     // check if we can read the .in file
-    string name_in= project_name+".in";
-    const char* file_in=name_in.c_str();
+    string name_in = project_name + ".in";
+    const char* file_in = name_in.c_str();
     ifstream in2;
-    in2.open(file_in,ifstream::in);
-    if (in2.is_open()==false) {
-        //check if user added ".in" and ignore it in this case
-        string suffix (".in");
+    in2.open(file_in, ifstream::in);
+    if (in2.is_open() == false) {
+        // check if user added ".in" and ignore it in this case
+        string suffix(".in");
         size_t found = project_name.rfind(suffix);
-        if (found!=string::npos) {
+        if (found != string::npos) {
             project_name.erase(found);
         }
-    } else {
+    }
+    else {
         in2.close();
     }
     project_name_set = true;
 }
 
 void OptionsHandler::setOutputDirName(const string& s) {
-    output_dir=s;
-    char slash='/';
-    #ifdef _WIN32 //for 32 and 64 bit windows
-        slash='\\';
-    #endif
-    if(output_dir[output_dir.size()-1]!=slash)
-        output_dir+=slash;
-    output_dir_set=true;
+    output_dir = s;
+    char slash = '/';
+#ifdef _WIN32  // for 32 and 64 bit windows
+    slash = '\\';
+#endif
+    if (output_dir[output_dir.size() - 1] != slash)
+        output_dir += slash;
+    output_dir_set = true;
 }
 
 bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOptions) {
-    //Analyzing short command line options
-    for (size_t i = 1; i <ShortOptions.size(); i++) {
+    // Analyzing short command line options
+    for (size_t i = 1; i < ShortOptions.size(); i++) {
         switch (ShortOptions[i]) {
             case '-':
                 break;
             case 'c':
-                verbose=true;
+                verbose = true;
                 break;
             case 'f':
                 write_extra_files = true;
@@ -198,47 +203,47 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
             case 'r':
                 to_compute.set(ConeProperty::Approximate);
                 break;
-            case 'e':  //check for arithmetic overflow
+            case 'e':  // check for arithmetic overflow
                 // test_arithmetic_overflow=true;
                 cerr << "WARNING: deprecated option -e is ignored." << endl;
                 break;
-            case 'B':  //use Big Integer
-                to_compute.set(ConeProperty::BigInt); // use_Big_Integer=true;
+            case 'B':                                  // use Big Integer
+                to_compute.set(ConeProperty::BigInt);  // use_Big_Integer=true;
                 break;
-            case 'b':  //use the bottom decomposition for the triangulation
+            case 'b':  // use the bottom decomposition for the triangulation
                 to_compute.set(ConeProperty::BottomDecomposition);
                 break;
-            case 'C':  //compute the class group
+            case 'C':  // compute the class group
                 to_compute.set(ConeProperty::ClassGroup);
                 break;
-            case 'k':  //keep the order of the generators in Full_Cone
+            case 'k':  // keep the order of the generators in Full_Cone
                 to_compute.set(ConeProperty::KeepOrder);
                 break;
-            case 'o':  //suppress bottom decomposition in Full_Cone
+            case 'o':  // suppress bottom decomposition in Full_Cone
                 to_compute.set(ConeProperty::NoBottomDec);
                 break;
             case 'M':  // compute minimal system of generators of integral closure
                        // as a module over original monoid
                 to_compute.set(ConeProperty::ModuleGeneratorsOverOriginalMonoid);
                 break;
-            case '?':  //print help text and exit
+            case '?':  // print help text and exit
                 return true;
                 break;
-            case 'x': //should be separated from other options
-                cerr<<"Error: Option -x=<T> has to be separated from other options"<<endl;
+            case 'x':  // should be separated from other options
+                cerr << "Error: Option -x=<T> has to be separated from other options" << endl;
                 exit(1);
                 break;
-            case 'I': 
+            case 'I':
                 to_compute.set(ConeProperty::Integral);
                 break;
-            case 'L': 
+            case 'L':
                 to_compute.set(ConeProperty::VirtualMultiplicity);
                 break;
-            case 'E': 
+            case 'E':
                 to_compute.set(ConeProperty::WeightedEhrhartSeries);
                 break;
             case 'i':
-                ignoreInFileOpt=true;
+                ignoreInFileOpt = true;
                 break;
             case 'H':
                 to_compute.set(ConeProperty::IntegerHull);
@@ -265,7 +270,7 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
                 to_compute.set(ConeProperty::ProjectionFloat);
                 break;
             default:
-                cerr<<"Error: Unknown option -"<<ShortOptions[i]<<endl;
+                cerr << "Error: Unknown option -" << ShortOptions[i] << endl;
                 exit(1);
                 break;
         }
@@ -273,34 +278,35 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
 
     // Remember to update also the --help text and the documentation when changing this!
     vector<string> AdmissibleOut;
-    string AdmissibleOutarray[]={"gen","cst","inv","ext","ht1","esp","egn","typ","lat","msp","mod"}; // "mod" must be last
-    for(size_t i=0;i<11;++i)
-        AdmissibleOut.push_back(AdmissibleOutarray[i]);
-    assert(AdmissibleOut.back()=="mod");
+    string AdmissibleOutarray[] = {"gen", "cst", "inv", "ext", "ht1", "esp",
+                                   "egn", "typ", "lat", "msp", "mod"};  // "mod" must be last
+    for (const auto& i : AdmissibleOutarray)
+        AdmissibleOut.push_back(i);
+    assert(AdmissibleOut.back() == "mod");
 
     // analyzing long options
-    for(size_t i=0; i<LongOptions.size();++i){ 
+    for (const auto& LongOption : LongOptions) {
         size_t j;
-        for(j=0;j<LongOptions[i].size();++j){
-            if(LongOptions[i][j]=='=')
-                break;            
+        for (j = 0; j < LongOption.size(); ++j) {
+            if (LongOption[j] == '=')
+                break;
         }
-        if(j<LongOptions[i].size()){
-            string OptName=LongOptions[i].substr(0,j);
-            string OptValue=LongOptions[i].substr(j+1,LongOptions[i].size()-1);
-            if(OptName=="OutputDir"){
+        if (j < LongOption.size()) {
+            string OptName = LongOption.substr(0, j);
+            string OptValue = LongOption.substr(j + 1, LongOption.size() - 1);
+            if (OptName == "OutputDir") {
                 setOutputDirName(OptValue);
                 continue;
             }
         }
-        if(LongOptions[i]=="help"){
-            return true; // indicate printing of help text
+        if (LongOption == "help") {
+            return true;  // indicate printing of help text
         }
-        if(LongOptions[i]=="verbose"){
-            verbose=true;
+        if (LongOption == "verbose") {
+            verbose = true;
             continue;
         }
-        if(LongOptions[i]=="version"){
+        if (LongOption == "version") {
             printVersion();
             exit(0);
         }
@@ -308,68 +314,68 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
             use_Big_Integer=true;
             continue;
         }*/
-        if(LongOptions[i]=="LongLong"){
-            use_long_long=true;
+        if (LongOption == "LongLong") {
+            use_long_long = true;
             continue;
         }
-        if(LongOptions[i]=="NoExtRaysOutput"){
-            no_ext_rays_output=true;
+        if (LongOption == "NoExtRaysOutput") {
+            no_ext_rays_output = true;
             continue;
         }
-        if(LongOptions[i]=="NoSuppHypsOutput"){
-            no_supp_hyps_output=true;
+        if (LongOption == "NoSuppHypsOutput") {
+            no_supp_hyps_output = true;
             continue;
         }
-        if(LongOptions[i]=="NoMatricesOutput"){
-            no_matrices_output=true;
+        if (LongOption == "NoMatricesOutput") {
+            no_matrices_output = true;
             continue;
         }
-        if(LongOptions[i]=="ignore"){
-            ignoreInFileOpt=true;
+        if (LongOption == "ignore") {
+            ignoreInFileOpt = true;
             continue;
         }
-        if(LongOptions[i]=="files"){
+        if (LongOption == "files") {
             write_extra_files = true;
             continue;
         }
-        if(LongOptions[i]=="all-files"){
+        if (LongOption == "all-files") {
             write_all_files = true;
             continue;
         }
-        if(find(AdmissibleOut.begin(),AdmissibleOut.end(),LongOptions[i])!=AdmissibleOut.end()){
-            OutFiles.push_back(LongOptions[i]);
+        if (find(AdmissibleOut.begin(), AdmissibleOut.end(), LongOption) != AdmissibleOut.end()) {
+            OutFiles.push_back(LongOption);
             continue;
         }
         try {
-            to_compute.set(toConeProperty(LongOptions[i]));
+            to_compute.set(toConeProperty(LongOption));
             continue;
-        } catch (const BadInputException& ) {};
-        cerr << "Error: Unknown option --" << LongOptions[i] << endl;
+        } catch (const BadInputException&) {
+        };
+        cerr << "Error: Unknown option --" << LongOption << endl;
         exit(1);
     }
-    
-    if(output_dir_set){
-        output_file=output_dir+pureName(project_name);
+
+    if (output_dir_set) {
+        output_file = output_dir + pureName(project_name);
     }
     else
-        output_file=project_name;
-    
-    
+        output_file = project_name;
 
-    return false; //no need to print help text
+    return false;  // no need to print help text
 }
 
-template<typename Integer>
+template <typename Integer>
 void OptionsHandler::applyOutputOptions(Output<Integer>& Out) {
-    if(no_ext_rays_output)
+    if (no_ext_rays_output)
         Out.set_no_ext_rays_output();
-    if(no_supp_hyps_output)
+    if (no_supp_hyps_output)
         Out.set_no_supp_hyps_output();
-    if(no_matrices_output)
+    if (no_matrices_output)
         Out.set_no_matrices_output();
-    if(write_all_files) {
+    if (write_all_files) {
         Out.set_write_all_files();
-    } else if (write_extra_files) {
+    }
+    else if (write_extra_files) {
         Out.set_write_extra_files();
     }
     if (to_compute.test(ConeProperty::Triangulation) || to_compute.test(ConeProperty::ConeDecomposition)) {
@@ -384,51 +390,58 @@ void OptionsHandler::applyOutputOptions(Output<Integer>& Out) {
     }
     if (to_compute.test(ConeProperty::FaceLattice)) {
         Out.set_write_fac(true);
-        Out.set_write_cst(true);
-        Out.set_write_inv(true);
     }
-    for(size_t i=0;i<OutFiles.size();++i){
-        if(OutFiles[i]=="gen"){
+    if (to_compute.test(ConeProperty::Incidence)) {
+        Out.set_write_inc(true);
+    }
+    if (to_compute.test(ConeProperty::ExploitAutomsVectors) || to_compute.test(ConeProperty::ExploitAutomsMult) ||
+        to_compute.test(ConeProperty::Automorphisms) || to_compute.test(ConeProperty::AmbientAutomorphisms) ||
+        to_compute.test(ConeProperty::CombinatorialAutomorphisms) || to_compute.test(ConeProperty::RationalAutomorphisms) ||
+        to_compute.test(ConeProperty::EuclideanAutomorphisms)) {
+        Out.set_write_aut(true);
+    }
+    for (const auto& OutFile : OutFiles) {
+        if (OutFile == "gen") {
             Out.set_write_gen(true);
             continue;
         }
-        if(OutFiles[i]=="cst"){
+        if (OutFile == "cst") {
             Out.set_write_cst(true);
             continue;
         }
-        if(OutFiles[i]=="inv"){
+        if (OutFile == "inv") {
             Out.set_write_inv(true);
             continue;
         }
-        if(OutFiles[i]=="ht1"){
+        if (OutFile == "ht1") {
             Out.set_write_ht1(true);
             continue;
         }
-        if(OutFiles[i]=="ext"){
+        if (OutFile == "ext") {
             Out.set_write_ext(true);
             continue;
         }
-        if(OutFiles[i]=="egn"){
+        if (OutFile == "egn") {
             Out.set_write_egn(true);
             continue;
         }
-        if(OutFiles[i]=="esp"){
+        if (OutFile == "esp") {
             Out.set_write_esp(true);
             continue;
         }
-        if(OutFiles[i]=="typ"){
+        if (OutFile == "typ") {
             Out.set_write_typ(true);
             continue;
         }
-        if(OutFiles[i]=="lat"){
+        if (OutFile == "lat") {
             Out.set_write_lat(true);
             continue;
         }
-        if(OutFiles[i]=="msp"){
+        if (OutFile == "msp") {
             Out.set_write_msp(true);
             continue;
         }
-        if(OutFiles[i]=="mod"){
+        if (OutFile == "mod") {
             Out.set_write_mod(true);
             continue;
         }
@@ -442,28 +455,27 @@ void OptionsHandler::applyOutputOptions(Output<Integer>& Out) {
 }
 
 bool OptionsHandler::activateDefaultMode() {
-    if (to_compute.goals().none() && !to_compute.test(ConeProperty::DualMode) ){
+    if (to_compute.goals().none() && !to_compute.test(ConeProperty::DualMode)) {
         to_compute.set(ConeProperty::DefaultMode);
         return true;
     }
     return false;
 }
 
-string pureName(const string& fullName){
-// extracts the pure filename
+string pureName(const string& fullName) {
+    // extracts the pure filename
 
-    string slash="/";
-    #ifdef _WIN32 //for 32 and 64 bit windows
-        slash="\\";
-    #endif
+    string slash = "/";
+#ifdef _WIN32  // for 32 and 64 bit windows
+    slash = "\\";
+#endif
     size_t found = fullName.rfind(slash);
-    if(found==std::string::npos)
-        return(fullName);
+    if (found == std::string::npos)
+        return (fullName);
     found++;
-    size_t length=fullName.size()-found;
-    
+    size_t length = fullName.size() - found;
+
     // cout << "**************************** " << fullName.substr(found,length) << endl;
     // exit(1);
-    return(fullName.substr(found,length));  	
-
+    return (fullName.substr(found, length));
 }
\ No newline at end of file
